@@ -16,7 +16,7 @@ our @EXPORT = qw/printW printfW warnW sayW dieW/;
 our @EXPORT_OK = qw//;
 our %EXPORT_TAGS = ('all' => [@EXPORT, @EXPORT_OK]);
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 # default std handle
 my $STD_HANDLE = {
@@ -109,7 +109,7 @@ sub sayW {
 # warn Unicode to Console
 sub warnW {
     my $str = join q{}, @_;
-    $str .= $str =~ s/\n$// ? "\n" : Carp::shortmess('');
+    $str .= $str =~ s/\n$// ? "\n" : _shortmess();
     
     if (ref $SIG{__WARN__} eq 'CODE') {
         return $SIG{__WARN__}->($str);
@@ -122,7 +122,7 @@ sub warnW {
 # die Unicode to Console
 sub dieW {
     my $str = join q{}, @_;
-    $str .= $str =~ s/\n$// ? "\n" : Carp::shortmess('');
+    $str .= $str =~ s/\n$// ? "\n" : _shortmess();
     
     if (ref $SIG{__DIE__} eq 'CODE') {
         $SIG{__DIE__}->($str);
@@ -135,6 +135,10 @@ sub dieW {
     return;
 }
 
+sub _shortmess {
+    CYGWIN ? Encode::decode_utf8(Carp::shortmess('')) : Encode::decode(cp932 => Carp::shortmess(''));
+}
+
 sub _row_warn {
     _ConsoleOut(STD_ERROR_HANDLE, CONSOLE_ERROR_HANDLE, @_);
 }
